package com.ruoyi.os.mapper;

import java.util.List;
import com.ruoyi.os.domain.HealthcareOsConventionalValue;
import org.apache.ibatis.annotations.Mapper;

/**
 * 字典Mapper接口
 *
 * @author 何顺
 * @date 2024-09-29
 */
@Mapper
public interface HealthcareOsConventionalValueMapper
{
    /**
     * 查询字典
     *
     * @param id 字典主键
     * @return 字典
     */
    public HealthcareOsConventionalValue selectHealthcareOsConventionalValueById(Long id);

    /**
     * 查询字典列表
     *
     * @param healthcareOsConventionalValue 字典
     * @return 字典集合
     */
    public List<HealthcareOsConventionalValue> selectHealthcareOsConventionalValueList(HealthcareOsConventionalValue healthcareOsConventionalValue);

    /**
     * 新增字典
     *
     * @param healthcareOsConventionalValue 字典
     * @return 结果
     */
    public int insertHealthcareOsConventionalValue(HealthcareOsConventionalValue healthcareOsConventionalValue);

    /**
     * 修改字典
     *
     * @param healthcareOsConventionalValue 字典
     * @return 结果
     */
    public int updateHealthcareOsConventionalValue(HealthcareOsConventionalValue healthcareOsConventionalValue);

    /**
     * 删除字典
     *
     * @param id 字典主键
     * @return 结果
     */
    public int deleteHealthcareOsConventionalValueById(Long id);

    /**
     * 批量删除字典
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthcareOsConventionalValueByIds(Long[] ids);
}
